@@ -3,7 +3,7 @@ from typing import Tuple, List, Dict, Union
 from geopandas import GeoDataFrame
 from shapely.geometry import Polygon
 
-from map_poster_creator.color_schemes import base_color_scheme
+from map_poster_creator.color_schemes import get_color_schemes
 from map_poster_creator.geojson import get_polygon_from_geojson, get_map_geometry_from_poly, MapGeometry
 from map_poster_creator.logs import log_processing, logging
 from map_poster_creator.plotting import plot_and_save
@@ -12,21 +12,21 @@ logger = logging.getLogger(__name__)
 
 
 @log_processing
-def get_roads_data(shp_path: str):
+def get_roads_data(shp_path: str) -> GeoDataFrame:
     roads = GeoDataFrame.from_file(f"{shp_path}/gis_osm_roads_free_1.shp", encoding='utf-8')
-    return roads
+    return roads  # TODO: Add Path or os.path
 
 
 @log_processing
-def get_water_data(shp_path: str):
+def get_water_data(shp_path: str) -> GeoDataFrame:
     water = GeoDataFrame.from_file(f"{shp_path}/gis_osm_water_a_free_1.shp", encoding='utf-8')
-    return water
+    return water  # TODO: Add Path or os.path
 
 
 @log_processing
-def get_greens_data(shp_path: str):
+def get_greens_data(shp_path: str) -> GeoDataFrame:
     greens = GeoDataFrame.from_file(f"{shp_path}/gis_osm_pois_a_free_1.shp", encoding='utf-8')
-    return greens
+    return greens  # TODO: Add Path or os.path
 
 
 @log_processing
@@ -53,10 +53,11 @@ def preprocessing_other(poly: Polygon, dataframe: GeoDataFrame) -> GeoDataFrame:
 def create_poster(
         base_shp_path: str,
         geojson_path: str,
-        colors: List[str],
+        colors: Union[List[Union[Dict, str]], None],
         layers: List[str],
         config: dict,
         output_prefix: str,
+        user_color_scheme: bool = False,
 ):
     poly, geometry = get_boundary_shape(geojson=geojson_path)
     roads = get_roads_data(base_shp_path)
@@ -65,10 +66,11 @@ def create_poster(
     roads_df = preprocessing_roads(poly=poly, roads=roads)
     water_df = preprocessing_other(poly=poly, dataframe=water)
     greens_df = preprocessing_other(poly=poly, dataframe=greens)
+    # TODO: Support user color scheme
     for color in colors:
-        if color not in base_color_scheme.keys():
+        if color not in get_color_schemes().keys():
             logger.warning(f"Color {color} not found in base color scheme. "
-                           f"Available colors {' '.join(base_color_scheme.keys())}")
+                           f"Available colors: {', '.join(get_color_schemes().keys())}")
         print("")
         print(f"Plot and Save {color} map")
         plot_and_save(
@@ -78,5 +80,5 @@ def create_poster(
             geometry=geometry,
             path=f'{output_prefix}_{color}.png',
             dpi=1200,
-            color=base_color_scheme[color]
+            color=get_color_schemes()[color]
         )
